# Scheduler & Alarms CLI

A simple CLI application to schedule jobs, run tasks, use recurrence rules, prevent overlapping runs, and handle shutdown gracefully.

## Commands

### Add job
### Add interval job
### List jobs
### Start scheduler
## Features
- Recurrence rules (daily, weekly, hourly, interval).
- Thread pool for task execution.
- Prevent overlapping job runs.
- Persistent job storage.
- Graceful shutdown.
